@@ -579,3 +579,25 @@ async def test_futures_coin_get_position_mode(futuresClientAsync):
 async def test_futures_coin_stream_close(futuresClientAsync):
     listen_key = await futuresClientAsync.futures_coin_stream_get_listen_key()
     await futuresClientAsync.futures_coin_stream_close(listenKey=listen_key)
+
+
+@pytest.mark.skip(reason="No sandbox support")
+async def test_futures_coin_account_order_history_download(futuresClientAsync):
+    await futuresClientAsync.futures_coin_account_order_download()
+
+
+@pytest.mark.skip(reason="No sandbox support")
+async def test_futures_coin_account_order_download_id(futuresClientAsync):
+    await futuresClientAsync.futures_coin_account_order_download_link(downloadId="123")
+
+
+@pytest.mark.skip(reason="No sandbox support")
+async def test_futures_coin_account_trade_history_download(futuresClientAsync):
+    await futuresClientAsync.futures_coin_account_trade_history_download()
+
+
+@pytest.mark.skip(reason="No sandbox support")
+async def test_futures_coin_account_trade_download_id(futuresClientAsync):
+    await futuresClientAsync.futures_coin_account_trade_history_download_link(
+        downloadId="123"
+    )
